Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
path: root/src/ui/ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ui/ui.h')
-rw-r--r--src/ui/ui.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/ui/ui.h b/src/ui/ui.h
index 4b5d2da..aaf4acc 100644
--- a/src/ui/ui.h
+++ b/src/ui/ui.h
@@ -98,15 +98,17 @@ public:
* */
static math::Vector2f elementsize;
/**
* global spacing between ui elements, used by resize() functions
* */
- static float spacing;
+ static float padding;
/**
* global margin for frames and widgets, used by resize() functions
* see @Widget::resize();
* */
static float margin;
+ static float pointer_size;
+
protected:
/* -- event handlers --------------------------------------- */
@@ -98,15 +98,17 @@ public:
static math::Vector2f elementsize;
/**
- * global spacing between ui elements, used by resize() functions
+ * global padding between ui elements, used by resize() functions
* */